# Exceptions

## Error

::: pyflp.exceptions.Error

## DataCorruptionDetectedError

::: pyflp.exceptions.DataCorruptionDetectedError

## OperationNotPermittedError

::: pyflp.exceptions.OperationNotPermittedError
